@@ -1,6 +1,6 @@
 from .server import *
 from .client import *
 
-version = "0.0.27"
-keywords = ["encrypted socket server"]
+version = "0.1.2"
+keywords = ["encrypted socket server client"]
 entry = "test:main"
