@@ -15,28 +15,28 @@ class SC(object):
         self.key = None
         if self.encrypted:
             ingredients = self.request("get_akey")
-            self.b = randno()
-            self.g = ingredients["g"]
-            self.p = ingredients["p"]
-            self.bkey = pow(self.g, self.b, self.p)
-            self.request("set_bkey", self.bkey)
-            self.key = str(pow(ingredients["akey"], self.b, self.p))
+            b = randi()
+            g = ingredients["g"]
+            p = ingredients["p"]
+            bkey = pow(g, b, p)
+            self.request("set_bkey", bkey)
+            self.key = str(pow(ingredients["akey"], b, p))
 
     def request(self, command: str, data: Any = None) -> Any:
         request = dict(command=command, data=data)
         try:
-            request = json.dumps(request).encode("utf-8")
+            request = utf8e(jd(request))
         except:
             request = pickle.dumps(request)
         if self.encrypted and self.key:
             request = encrypt(self.key, request)
         self.s.send(request)
         while True:
-            response = self.s.recv(1024*4).decode("utf-8")
+            response = utf8d(self.s.recv(1024*4))
             if response:
                 if self.encrypted and self.key:
                     return decrypt(self.key, response)
                 else:
-                    return json.loads(response)
+                    return jl(response)
 
 
